@@ -1,11 +1,11 @@
 modelDisable <- function(factory){
     command <- paste("UpdaterMethods.SetFactory('", factory,"');UpdaterMethods.Disable", sep = "")
-    invisible(.C("CmdInterpreter", command, nchar(command), integer(1)))
+    invisible(.CmdInterpreter(command))
 
 }
 
 
 modelEnable <- function(factory){
     command <- paste("UpdaterMethods.SetFactory('", factory,"');UpdaterMethods.Enable", sep = "")
-    invisible(.C("CmdInterpreter", command, nchar(command), integer(1)))
+    invisible(.CmdInterpreter(command))
 }
