@@ -5,6 +5,5 @@ function(endIt)
     if(!is.numeric(endIt))
         stop("endIt ", "must be numeric")
     endIt <- as.integer(endIt)
-    command <- paste("SamplesEmbed.end :=", endIt)
-    invisible(.C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs"))
+    options("BRugsSamplesEnd" = endIt)
 }
